@@ -21,7 +21,7 @@
 #ifndef KSCREEN_CONFIGOPERATION_H
 #define KSCREEN_CONFIGOPERATION_H
 
-#include <QtCore/QObject>
+#include <QObject>
 
 #include "kscreen_export.h"
 #include "types.h"
@@ -41,7 +41,7 @@ public:
     };
     Q_DECLARE_FLAGS(Options, Option)
 
-    virtual ~ConfigOperation();
+    ~ConfigOperation() override;
 
     bool hasError() const;
     QString errorString() const;
@@ -54,7 +54,7 @@ Q_SIGNALS:
     void finished(ConfigOperation *operation);
 
 protected:
-    explicit ConfigOperation(ConfigOperationPrivate *dd, QObject *parent = 0);
+    explicit ConfigOperation(ConfigOperationPrivate *dd, QObject *parent = nullptr);
 
     void setError(const QString &error);
     void emitResult();
@@ -64,7 +64,7 @@ protected Q_SLOTS:
 
 protected:
     ConfigOperationPrivate * const d_ptr;
-    Q_DECLARE_PRIVATE(ConfigOperation);
+    Q_DECLARE_PRIVATE(ConfigOperation)
 };
 }
 
